##  Statuses
Decision-makers, such as lead enterprise architects, evaluate architecture decisions to assign appropriate statuses. These statuses help streamline decision management and ensure clarity in the approval process. You can update the decision status at any time. Available statuses include:
  * Draft
  * Proposed
  * Accepted
  * Rejected
  * Superseded
  * Deprecated
